Module validators

Module validators 

Structs

SimpleDiagnostic
Represents a simplified, serializable diagnostic message.
ValidationContext
Violation
ViolationRange

Enums

ValidatorType
Validator type (sync or async).

Constants

DETECTOR_FACTORIES

Traits

ValidatorAsync
Validates the given Context and returns a list of the violations grouped by filename.
ValidatorDetector
Detects a ValidatorType for the given block (if any).
ValidatorSync

Functions

detect_validators
run
Run the given sync and async validators in separate threads in parallel.